timerelationtools.offset_happens_when_timespan_starts
=====================================================

.. autofunction:: abjad.tools.timerelationtools.offset_happens_when_timespan_starts.offset_happens_when_timespan_starts
   :noindex:
